# eric7.Plugins.VcsPlugins.vcsMercurial.HisteditExtension.histedit

Module implementing the histedit extension interface.

### Global Attributes

None

### Classes

Histedit | Class implementing the histedit extension interface.

### Functions

None

## Histedit

Class implementing the histedit extension interface.

### Derived from

HgExtension

### Class Attributes

None

### Class Methods

None

### Methods

Histedit | Constructor
hgHisteditAbort | Public method to abort an interrupted histedit session.
hgHisteditContinue | Public method to continue an interrupted histedit session.
hgHisteditEditPlan | Public method to edit the remaining actions list of an interrupted histedit session.
hgHisteditStart | Public method to start a histedit session.

### Static Methods

None

#### Histedit (Constructor)

Histedit(vcs, ui=None)

Constructor

vcs (Hg)
  reference to the Mercurial vcs object
ui (QWidget)
  reference to a UI widget (defaults to None)

#### Histedit.hgHisteditAbort

hgHisteditAbort()

Public method to abort an interrupted histedit session.

Return:
  flag indicating that the project should be reread

Return Type:
  bool

#### Histedit.hgHisteditContinue

hgHisteditContinue()

Public method to continue an interrupted histedit session.

Return:
  flag indicating that the project should be reread

Return Type:
  bool

#### Histedit.hgHisteditEditPlan

hgHisteditEditPlan()

Public method to edit the remaining actions list of an interrupted histedit session.

Return:
  flag indicating that the project should be reread

Return Type:
  bool

#### Histedit.hgHisteditStart

hgHisteditStart(rev="")

Public method to start a histedit session.

rev (str)
  revision to start histedit at

Return:
  flag indicating that the project should be reread

Return Type:
  bool

Up